==> keyclic_sdk_api-2.2.30.tar.gz: lib/api/workflow_api.dart <==
part of keyclic_sdk_api.api;

class WorkflowApi {
  WorkflowApi([ApiClient apiClient])
      : apiClient = apiClient ?? defaultApiClient;

  final ApiClient apiClient;

  /// Retrieve one Workflow resource.
  ///
  ///
  Future<Workflow> getWorkflow(
    String xKeyclicApp,
    String workflow, {
    String acceptLanguage,
    DateTime xDateTime,
    String xKeyclicAppVersion,
  }) async {
    // verify required params are set

    if (xKeyclicApp == null) {
      throw ApiException(0, "Missing required param: xKeyclicApp");
    }

    if (workflow == null) {
      throw ApiException(0, "Missing required param: workflow");
    }

    // create path and map variables
    final String path = "/workflows/{workflow}"
        .replaceAll("{format}", "json")
        .replaceAll("{" + "workflow" + "}", workflow.toString());

    // query params
    final List<QueryParam> queryParams = [];

    // header params
    final Map<String, String> headerParams = {
      "accept-language": acceptLanguage,
      if (xDateTime is DateTime) "x-date-time": xDateTime.toIso8601String(),
      "x-keyclic-app": xKeyclicApp,
      "x-keyclic-app-version": xKeyclicAppVersion,
    };

    final List<String> contentTypes = [
      "application/json;charset=UTF-8",
      "application/json",
    ];

    final List<String> authNames = [
      "bearer",
    ];

    final Object postBody = null;

    final Response response = await apiClient.invokeAPI(
      path,
      'GET',
      queryParams,
      postBody,
      headerParams,
      contentTypes[0],
      authNames,
    );

    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode, response.body);
    }

    if (response.body == null) {
      return null;
    }

    return apiClient.deserialize(response.body, 'Workflow') as Workflow;
  }
}

==> keyclic_sdk_api-2.4.19.tar.gz: lib/api/workflow_api.dart <==
part of keyclic_sdk_api.api;

class WorkflowApi {
  WorkflowApi([ApiClient apiClient])
      : apiClient = apiClient ?? defaultApiClient;

  final ApiClient apiClient;

  /// Retrieve one Workflow resource.
  ///
  ///
  Future<Workflow> getWorkflow(
    String xKeyclicApp,
    String workflow, {
    String acceptLanguage,
    DateTime xDateTime,
    String xKeyclicAppVersion,
  }) async {
    // verify required params are set

    if (xKeyclicApp == null) {
      throw ApiException(0, "Missing required param: xKeyclicApp");
    }

    if (workflow == null) {
      throw ApiException(0, "Missing required param: workflow");
    }

    // create path and map variables
    final String path = "/workflows/{workflow}"
        .replaceAll("{format}", "json")
        .replaceAll("{" + "workflow" + "}", workflow.toString());

    // query params
    final List<QueryParam> queryParams = <QueryParam>[];

    // header params
    final Map<String, String> headerParams = <String, String>{
      "accept-language": acceptLanguage,
      if (xDateTime is DateTime) "x-date-time": xDateTime.toIso8601String(),
      "x-keyclic-app": xKeyclicApp,
      "x-keyclic-app-version": xKeyclicAppVersion,
    };

    final List<String> contentTypes = <String>[
      "application/json;charset=UTF-8",
      "application/json",
    ];

    final List<String> authNames = <String>[
      "bearer",
    ];

    final Response response = await apiClient.invokeAPI(
      path: path,
      method: 'GET',
      queryParams: queryParams,
      headerParams: headerParams,
      contentType: contentTypes[0],
      authNames: authNames,
    );

    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode, response.body);
    }

    if (response.body == null) {
      return null;
    }

    return apiClient.deserialize(response.body, 'Workflow') as Workflow;
  }
}
